summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberchatsession.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/jabber/jabberchatsession.cpp
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/jabberchatsession.cpp')
-rw-r--r--kopete/protocols/jabber/jabberchatsession.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/jabberchatsession.cpp b/kopete/protocols/jabber/jabberchatsession.cpp
index dbe35ab6..38ea726f 100644
--- a/kopete/protocols/jabber/jabberchatsession.cpp
+++ b/kopete/protocols/jabber/jabberchatsession.cpp
@@ -117,8 +117,8 @@ void JabberChatSession::slotUpdateDisplayName ()
if ( !mResource.isEmpty () )
jid.setResource ( mResource );
- TQString statusText = i18n("a contact's online status in parenthesis.", " (%1)")
- .arg( chatMembers.first()->onlineStatus().description() );
+ TQString statusText = i18n("a contact's online status in tqparenthesis.", " (%1)")
+ .tqarg( chatMembers.first()->onlinetqStatus().description() );
if ( jid.resource().isEmpty () )
setDisplayName ( chatMembers.first()->metaContact()->displayName () + statusText );
else
@@ -225,7 +225,7 @@ void JabberChatSession::slotSendTypingNotification ( bool typing )
// create JID for us as sender
XMPP::Jid fromJid = static_cast<const JabberBaseContact*>(myself())->rosterItem().jid();
- fromJid.setResource ( account()->configGroup()->readEntry( "Resource", TQString::null ) );
+ fromJid.setResource ( account()->configGroup()->readEntry( "Resource", TQString() ) );
kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Sending out typing notification (" << typing << ") to all chat members." << endl;
@@ -253,7 +253,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
jabberMessage.setSubject ( message.subject () );
jabberMessage.setTimeStamp ( message.timestamp () );
- if ( message.plainBody().find ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
+ if ( message.plainBody().tqfind ( "-----BEGIN PGP MESSAGE-----" ) != -1 )
{
/*
* This message is encrypted, so we need to set
@@ -270,7 +270,7 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
// remove PGP header and footer from message
encryptedBody.truncate ( encryptedBody.length () - TQString("-----END PGP MESSAGE-----").length () - 2 );
- encryptedBody = encryptedBody.right ( encryptedBody.length () - encryptedBody.find ( "\n\n" ) - 2 );
+ encryptedBody = encryptedBody.right ( encryptedBody.length () - encryptedBody.tqfind ( "\n\n" ) - 2 );
// assign payload to message
jabberMessage.setXEncrypted ( encryptedBody );
@@ -286,16 +286,16 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
{
TQString xhtmlBody = message.escapedBody();
// According to JEP-0071 8.9 it is only RECOMMANDED to replace \n with <br/>
// which mean that some implementation (gaim 2 beta) may still think that \n are linebreak.
// and considered the fact that KTextEditor generate a well indented XHTML, we need to remove all \n from it
// see Bug 121627
// Anyway, theses client that do like that are *WRONG* considreded the example of jep-71 where there are lot of
// linebreak that are not interpreted. - Olivier 2006-31-03
- xhtmlBody.replace("\n","");
+ xhtmlBody.tqreplace("\n","");
//&nbsp; is not a valid XML entity
- xhtmlBody.replace("&nbsp;" , "&#160;");
+ xhtmlBody.tqreplace("&nbsp;" , "&#160;");
// Remove trailing line break
xhtmlBody.remove( TQRegExp( "<br/>$" ) );
@@ -358,4 +358,4 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
#include "jabberchatsession.moc"
// vim: set noet ts=4 sts=4 sw=4:
-// kate: tab-width 4; replace-tabs off; space-indent off;
+// kate: tab-width 4; tqreplace-tabs off; space-indent off;
@@ -286,16 +286,16 @@ void JabberChatSession::slotMessageSent ( Kopete::Message &message, Kopete::Chat
{
TQString xhtmlBody = message.escapedBody();
- // According to JEP-0071 8.9 it is only RECOMMANDED to replace \n with <br/>
+ // According to JEP-0071 8.9 it is only RECOMMANDED to tqreplace \n with <br/>
// which mean that some implementation (gaim 2 beta) may still think that \n are linebreak.
// and considered the fact that KTextEditor generate a well indented XHTML, we need to remove all \n from it